body {
    background: #1e1e22;
    color: white;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol";
    font-size: 17px;
}

h1 {
    margin-top: 0;
    margin-bottom: 20px;
}

input {
    font-size: inherit;
    width: 100%;
}

.form-submit-button {
    background: #4a4a4a;
    border: none;
    color: white;
    padding: 4px;
    text-align: center;
    text-decoration: none;
    display: inline-block;
    font-size: 17px;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol";
    margin: 4px 2px;
    border-radius: 12px;
    width: 50%;
}

.form-submit-button:hover {
	background: #2f2f2f;
}

.center_children {
    display: flex;
    align-content: center;
    align-items: center;
    text-align: center;
    justify-content: center;
}

#logo {
    position: absolute;
    left: 10px;
    top: 10px;
    min-height: 5%;

}

#window {
    height: 98%;
    width: 99%;
    position: absolute;
    margin: 0;
    padding: 0;
}

#main {
    display: flex;
    flex-direction: column;
}

#go_to_server_button {
    width: 75%
}